@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Bulk;
-$Search::Elasticsearch::Bulk::VERSION = '1.20';
+$Search::Elasticsearch::Bulk::VERSION = '1.99';
 use Moo;
 with 'Search::Elasticsearch::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Sync';
@@ -14,6 +14,7 @@ sub add_action {
     my $buffer    = $self->_buffer;
     my $max_size  = $self->max_size;
     my $max_count = $self->max_count;
+    my $max_time  = $self->max_time;
 
     while (@_) {
         my @json = $self->_encode_action( splice( @_, 0, 2 ) );
@@ -27,8 +28,9 @@ sub add_action {
         my $count = $self->_buffer_count( $self->_buffer_count + 1 );
 
         $self->flush
-            if ( $max_size && $size >= $max_size )
-            || $max_count && $count >= $max_count;
+            if ( $max_size and $size >= $max_size )
+            || ( $max_count and $count >= $max_count )
+            || ( $max_time  and time >= $self->_last_flush + $max_time );
     }
     return 1;
 }
@@ -37,6 +39,7 @@ sub add_action {
 sub flush {
 #===================================
     my $self = shift;
+    $self->_last_flush(time);
 
     return { items => [] }
         unless $self->_buffer_size;
@@ -108,7 +111,7 @@ Search::Elasticsearch::Bulk - A helper module for the Bulk API and for reindexin
 
 =head1 VERSION
 
-version 1.20
+version 1.99
 
 =head1 SYNOPSIS
 
@@ -178,6 +181,7 @@ L<Search::Elasticsearch::Role::Is_Sync>.
 
         max_count   => 1_000,               # optional
         max_size    => 1_000_000,           # optional
+        max_time    => 5,                   # optional
 
         verbose     => 0 | 1,               # optional
 
@@ -209,8 +213,8 @@ a L<bulk()|Search::Elasticsearch::Client::1_0::Direct/bulk()> request.
 
 =head2 Auto-flushing
 
-An automatic L</flush()> is triggered whenever the C<max_count> or C<max_size>
-threshold is breached.  This causes all actions in the buffer to be
+An automatic L</flush()> is triggered whenever the C<max_count>, C<max_size>,
+or C<max_time> threshold is breached.  This causes all actions in the buffer to be
 sent to Elasticsearch.
 
 =over
@@ -227,6 +231,12 @@ The maximum size of JSON request body to allow before triggering a
 L</flush()>.  This can be disabled by setting C<max_size> to C<0>.  Defaults
 to C<1_000,000> bytes.
 
+=item * C<max_time>
+
+The maximum number of seconds to wait before triggering a flush.  Defaults
+to C<0> seconds, which means that it is disabled.  B<Note:> This timeout
+is only triggered when new items are added to the queue, not in the background.
+
 =back
 
 =head2 Errors when flushing
