@@ -1,7 +1,7 @@
-package Search::Elasticsearch::Client::2_0::Direct::Nodes;
-$Search::Elasticsearch::Client::2_0::Direct::Nodes::VERSION = '1.20';
+package Search::Elasticsearch::Client::1_0::Direct::Nodes;
+$Search::Elasticsearch::Client::1_0::Direct::Nodes::VERSION = '1.99';
 use Moo;
-with 'Search::Elasticsearch::Role::API::2_0';
+with 'Search::Elasticsearch::Role::API::1_0';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('nodes');
 
@@ -13,11 +13,11 @@ __PACKAGE__->_install_api('nodes');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::2_0::Direct::Nodes - A client for running node-level requests
+Search::Elasticsearch::Client::1_0::Direct::Nodes - A client for running node-level requests
 
 =head1 VERSION
 
-version 1.20
+version 1.99
 
 =head1 DESCRIPTION
 
@@ -87,7 +87,7 @@ Allowed metrics are:
     C<transport>
 
 If the C<indices> metric (or C<_all>) is specified, then
-L<indices_stats|Search::Elasticsearch::Client::2_0::Direct::Indices/indices_stats()>
+L<indices_stats|Search::Elasticsearch::Client::1_0::Direct::Indices/indices_stats()>
 information is returned on a per-node basis. Which indices stats are
 returned can be controlled with the C<index_metric> parameter:
 
@@ -147,6 +147,22 @@ Query string parameters:
 See the L<hot_threads docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-hot-threads.html>
 for more information.
 
+=head2 C<shutdown()>
+
+    $e->nodes->shutdown(
+        node_id => $node_id | \@node_ids    # optional
+    );
+
+The C<shutdown()> method is used to shutdown one or more nodes, or the whole
+cluster.
+
+Query string parameters:
+    C<delay>,
+    C<exit>
+
+See the L<shutdown docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-nodes-shutdown.html>
+for more information.
+
 =head1 AUTHOR
 
 Clinton Gormley <drtech@cpan.org>
