@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Cxn::Hijk;
-$Search::Elasticsearch::Cxn::Hijk::VERSION = '1.20';
+$Search::Elasticsearch::Cxn::Hijk::VERSION = '1.99';
 use Moo;
 with 'Search::Elasticsearch::Role::Cxn::HTTP',
     'Search::Elasticsearch::Role::Cxn',
@@ -69,8 +69,10 @@ sub perform_request {
         $params,    # request
         $response->{status} || 500,    # code
         $response->{error},            # msg
-        $response->{body},             # body
-        \%head                         # headers
+        $response->{body}
+            || $response->{error_message}
+            || $response->{errno_string},    # body
+        \%head                               # headers
     );
 }
 
@@ -117,7 +119,7 @@ Search::Elasticsearch::Cxn::Hijk - A Cxn implementation which uses Hijk
 
 =head1 VERSION
 
-version 1.20
+version 1.99
 
 =head1 DESCRIPTION
 
@@ -170,6 +172,8 @@ From L<Search::Elasticsearch::Role::Cxn>
 
 =item * L<handle_args|Search::Elasticsearch::Role::Cxn/"handle_args">
 
+=item * L<handle_args|Search::Elasticsearch::Role::Cxn/"default_qs_params">
+
 =back
 
 =head1 SSL/TLS
