@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Error;
-$Search::Elasticsearch::Error::VERSION = '1.20';
+$Search::Elasticsearch::Error::VERSION = '1.99';
 use Moo;
 
 our $DEBUG = 0;
@@ -20,6 +20,9 @@ our $DEBUG = 0;
 @Search::Elasticsearch::Error::Missing::ISA
     = ( 'Search::Elasticsearch::Error::Request', __PACKAGE__ );
 
+@Search::Elasticsearch::Error::RequestTimeout::ISA
+    = ( 'Search::Elasticsearch::Error::Request', __PACKAGE__ );
+
 @Search::Elasticsearch::Error::ContentLength::ISA
     = ( __PACKAGE__, 'Search::Elasticsearch::Error::Request' );
 
@@ -165,7 +168,7 @@ Search::Elasticsearch::Error - Errors thrown by Search::Elasticsearch
 
 =head1 VERSION
 
-version 1.20
+version 1.99
 
 =head1 DESCRIPTION
 
@@ -224,6 +227,13 @@ is triggered by the C<409> HTTP status code.
 The request body was longer than the
 L<max_content_length|Search::Elasticsearch::Role::Cxn::HTTP/max_content_length>.
 
+=item * C<Search::Elasticsearch::Error::RequestTimeout>
+
+The request took longer than the specified C<timeout>.  Currently only
+applies to the
+L<cluster_health|Search::Elasticsearch::Client::2_0::Direct::Cluster/cluster_health()>
+request.
+
 =back
 
 =item * C<Search::Elasticsearch::Error::Timeout>
