@@ -1,17 +1,19 @@
 package Search::Elasticsearch::Role::Bulk;
-$Search::Elasticsearch::Role::Bulk::VERSION = '1.20';
+$Search::Elasticsearch::Role::Bulk::VERSION = '1.99';
 use Moo::Role;
 requires 'add_action', 'flush';
 
 use Search::Elasticsearch::Util qw(parse_params throw);
 use namespace::clean;
 
-has 'es'          => ( is => 'ro', required => 1 );
-has 'max_count'   => ( is => 'rw', default  => 1_000 );
-has 'max_size'    => ( is => 'rw', default  => 1_000_000 );
-has 'on_success'  => ( is => 'ro', default  => 0 );
+has 'es'        => ( is => 'ro', required => 1 );
+has 'max_count' => ( is => 'rw', default  => 1_000 );
+has 'max_size'  => ( is => 'rw', default  => 1_000_000 );
+has 'max_time'  => ( is => 'rw', default  => 0 );
+
+has 'on_success'  => ( is => 'ro', default => 0 );
 has 'on_error'    => ( is => 'lazy' );
-has 'on_conflict' => ( is => 'ro', default  => 0 );
+has 'on_conflict' => ( is => 'ro', default => 0 );
 has 'verbose'     => ( is => 'rw' );
 
 has '_buffer' => ( is => 'ro', default => sub { [] } );
@@ -19,11 +21,7 @@ has '_buffer_size'  => ( is => 'rw', default => 0 );
 has '_buffer_count' => ( is => 'rw', default => 0 );
 has '_serializer'   => ( is => 'lazy' );
 has '_bulk_args'    => ( is => 'ro' );
-
-our $Conflict = qr/
-    DocumentAlreadyExistsException
-  | :.version.conflict,.current.\[(\d+)\]
-  /x;
+has '_last_flush' => ( is => 'rw', default => sub {time} );
 
 our %Actions = (
     'index'  => 1,
@@ -33,9 +31,9 @@ our %Actions = (
 );
 
 our @Metadata_Keys = (
-    'index',  'type',      'id',  'routing',
-    'parent', 'timestamp', 'ttl', 'version',
-    'version_type'
+    'index',   'type',   'id',        'fields',
+    'routing', 'parent', 'timestamp', 'ttl',
+    'version', 'version_type'
 );
 
 #===================================
@@ -58,7 +56,8 @@ sub BUILDARGS {
 #===================================
     my ( $class, $params ) = parse_params(@_);
     my %args;
-    for (qw(index type consistency refresh replication timeout)) {
+    for (qw(index type consistency fields refresh replication routing timeout))
+    {
         $args{$_} = $params->{$_}
             if exists $params->{$_};
     }
@@ -191,9 +190,15 @@ sub _report {
         my ( $action, $result ) = %$item;
         my @args = ($action);
         if ( my $error = $result->{error} ) {
-            $on_conflict && $error =~ /$Conflict/
-                ? $on_conflict->( $action, $result, $j, $1 )
-                : $on_error && $on_error->( $action, $result, $j );
+            if ($on_conflict) {
+                my ( $is_conflict, $version )
+                    = $self->_is_conflict_error($error);
+                if ($is_conflict) {
+                    $on_conflict->( $action, $result, $j, $version );
+                    next;
+                }
+            }
+            $on_error && $on_error->( $action, $result, $j );
         }
         else {
             $on_success && $on_success->( $action, $result, $j );
@@ -202,6 +207,24 @@ sub _report {
     }
 }
 
+#===================================
+sub _is_conflict_error {
+#===================================
+    my ( $self, $error ) = @_;
+    my $version;
+    if ( ref($error) eq 'HASH' ) {
+        return 1 if $error->{type} eq 'document_already_exists_exception';
+        return unless $error->{type} eq 'version_conflict_engine_exception';
+        $error->{reason} =~ /version.conflict,.current.\[(\d+)\]/;
+        return ( 1, $1 );
+    }
+    return unless $error =~ /
+            DocumentAlreadyExistsException
+           |version.conflict,.current.\[(\d+)\]
+           /x;
+    return ( 1, $1 );
+}
+
 #===================================
 sub clear_buffer {
 #===================================
@@ -261,7 +284,7 @@ Search::Elasticsearch::Role::Bulk - Provides common functionality to L<Elasticse
 
 =head1 VERSION
 
-version 1.20
+version 1.99
 
 =head1 AUTHOR
 
