@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::Cxn;
-$Search::Elasticsearch::Role::Cxn::VERSION = '1.20';
+$Search::Elasticsearch::Role::Cxn::VERSION = '1.99';
 use Moo::Role;
 use Search::Elasticsearch::Util qw(throw);
 use List::Util qw(min);
@@ -24,12 +24,14 @@ has 'max_dead_timeout'      => ( is => 'ro', default  => 3600 );
 has 'serializer'            => ( is => 'ro', required => 1 );
 has 'logger'                => ( is => 'ro', required => 1 );
 has 'handle_args'           => ( is => 'ro', default  => sub { {} } );
+has 'default_qs_params'     => ( is => 'ro', default  => sub { {} } );
 
 my %Code_To_Error = (
     400 => 'Request',
     401 => 'Unauthorized',
     403 => 'Forbidden',
     404 => 'Missing',
+    408 => 'RequestTimeout',
     409 => 'Conflict',
     503 => 'Unavailable'
 );
@@ -216,7 +218,7 @@ Search::Elasticsearch::Role::Cxn - Provides common functionality to Cxn implemen
 
 =head1 VERSION
 
-version 1.20
+version 1.99
 
 =head1 DESCRIPTION
 
@@ -339,6 +341,17 @@ to ensure that you get information about healthy nodes from the cluster.
 Any default arguments which should be passed when creating a new instance of
 the class which handles the network transport, eg L<HTTP::Tiny>.
 
+=head2 C<default_qs_params>
+
+    $e = Search::Elasticsearch->new(
+        default_qs_params => {
+            session_key => 'my_session_key'
+        }
+    );
+
+Any values passed to C<default_qs_params> will be added to the query string
+of every request. Also see L<Search::Elasticsearch::Role::Cxn::HTTP/default_headers()>.
+
 =head1 METHODS
 
 None of the methods listed below are useful to the user. They are
