@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::Cxn::HTTP;
-$Search::Elasticsearch::Role::Cxn::HTTP::VERSION = '1.20';
+$Search::Elasticsearch::Role::Cxn::HTTP::VERSION = '1.99';
 use Moo::Role;
 
 use URI();
@@ -90,7 +90,8 @@ sub build_uri {
     my ( $self, $params ) = @_;
     my $uri = $self->uri->clone;
     $uri->path( $uri->path . $params->{path} );
-    $uri->query_form( $params->{qs} );
+    my %qs = ( %{ $self->default_qs_params }, %{ $params->{qs} || {} } );
+    $uri->query_form( \%qs );
     return $uri;
 }
 
@@ -167,7 +168,7 @@ Search::Elasticsearch::Role::Cxn::HTTP - Provides common functionality to HTTP C
 
 =head1 VERSION
 
-version 1.20
+version 1.99
 
 =head1 DESCRIPTION
 
@@ -292,6 +293,7 @@ to each request.
 The default headers that are passed with each request.  This includes
 the C<Accept-Encoding> header if C</deflate> is true, and the C<Authorization>
 header if C</userinfo> has a value.
+Also see L<Search::Elasticsearch::Role::Cxn/default_qs_params>.
 
 =head2 C<max_content_length()>
 
