@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::CxnPool::Sniff;
-$Search::Elasticsearch::Role::CxnPool::Sniff::VERSION = '1.20';
+$Search::Elasticsearch::Role::CxnPool::Sniff::VERSION = '1.99';
 use Moo::Role;
 with 'Search::Elasticsearch::Role::CxnPool';
 requires 'next_cxn', 'sniff';
@@ -45,7 +45,7 @@ sub parse_sniff {
         my $data = $nodes->{$node_id};
 
         my $host = $data->{ $protocol . "_address" } or next;
-        $host =~ s{^inet\[[^/]*/([^\]]+)\]}{$1} or next;
+        $host =~ s{^inet\[[^/]*/([^\]]+)\]}{$1};
 
         $host = $self->should_accept_node( $host, $node_id, $data )
             or next;
@@ -88,7 +88,7 @@ Search::Elasticsearch::Role::CxnPool::Sniff - A CxnPool role for connecting to a
 
 =head1 VERSION
 
-version 1.20
+version 1.99
 
 =head1 CONFIGURATION
 
