@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Util::API::QS;
-$Search::Elasticsearch::Util::API::QS::VERSION = '1.20';
+$Search::Elasticsearch::Util::API::QS::VERSION = '1.99';
 use strict;
 use warnings;
 
@@ -24,18 +24,18 @@ our %Handler = (
 );
 
 our %Params = (
-    active_only      => { type => 'bool' },
-    all              => { type => 'bool' },
-    allow_no_indices => { type => 'bool' },
-    analyze_wildcard => { type => 'bool' },
-    analyzer         => { type => 'string' },
-    boost_terms      => { type => 'number' },
-    bytes            => { type => 'enum', options => [ 'b', 'k', 'm', 'g' ] },
-    char_filters     => { type => 'list' },
-    clear            => { type => 'bool' },
-    completion       => { type => 'bool' },
+    active_only       => { type => 'bool' },
+    all               => { type => 'bool' },
+    allow_no_indices  => { type => 'bool' },
+    analyze_wildcard  => { type => 'bool' },
+    analyzer          => { type => 'string' },
+    boost_terms       => { type => 'number' },
+    bytes             => { type => 'enum', options => [ 'b', 'k', 'm', 'g' ] },
+    char_filters      => { type => 'list' },
+    clear             => { type => 'bool' },
+    completion        => { type => 'bool' },
     completion_fields => { type => 'list' },
-    consistency       => {
+    consistency => {
         options => [ 'one', 'quorum', 'all' ],
         type    => 'enum'
     },
@@ -68,6 +68,7 @@ our %Params = (
     filter_index_templates => { type => 'bool' },
     filter_indices         => { type => 'list' },
     filter_keys            => { type => 'bool' },
+    filter_path            => { type => 'list' },
     filter_metadata        => { type => 'bool' },
     filter_nodes           => { type => 'bool' },
     filter_routing_table   => { type => 'bool' },
@@ -165,6 +166,7 @@ our %Params = (
     pri                    => { type => 'bool' },
     process                => { type => 'bool' },
     q                      => { type => 'string' },
+    query                  => { type => 'bool' },
     query_cache            => { type => 'bool' },
     realtime               => { type => 'bool' },
     recovery               => { type => 'bool' },
@@ -175,7 +177,10 @@ our %Params = (
         options => [ 'sync', 'async' ],
         type    => 'enum'
     },
+    request           => { type => 'bool' },
+    request_cache     => { type => 'bool' },
     retry_on_conflict => { type => 'number' },
+    rewrite           => { type => 'bool' },
     routing           => { type => 'string' },
     script            => { type => 'string' },
     script_id         => { type => 'string' },
@@ -207,6 +212,7 @@ our %Params = (
     _source_exclude => { type => 'list', },
     _source_include => { type => 'list', },
     stats           => { type => 'list' },
+    status          => { type => 'string' },
     stop_words      => { type => 'list' },
     store           => { type => 'bool' },
     suggest_field   => { type => 'string' },
@@ -215,27 +221,28 @@ our %Params = (
         options => [ 'missing', 'popular', 'always' ],
         type    => 'enum'
     },
-    suggest_size    => { type => 'number' },
-    suggest_text    => { type => 'string' },
-    term_statistics => { type => 'bool' },
-    terminate_after => { type => 'number' },
-    text            => { type => 'string' },
-    thread_pool     => { type => 'bool' },
-    threads         => { type => 'number' },
-    timeout         => { type => 'duration' },
-    timestamp       => { type => 'datetime' },
-    tokenizer       => { type => 'string' },
-    track_scores    => { type => 'bool' },
-    transport       => { type => 'bool' },
-    ts              => { type => 'bool' },
-    ttl             => { type => 'duration' },
-    type            => { type => 'string' },
-    types           => { type => 'list' },
-    v               => { type => 'bool' },
-    verbose         => { type => 'bool' },
-    verify          => { type => 'bool' },
-    version         => { type => 'number' },
-    version_type    => {
+    suggest_size     => { type => 'number' },
+    suggest_text     => { type => 'string' },
+    term_statistics  => { type => 'bool' },
+    terminate_after  => { type => 'number' },
+    text             => { type => 'string' },
+    thread_pool      => { type => 'bool' },
+    threads          => { type => 'number' },
+    timeout          => { type => 'duration' },
+    timestamp        => { type => 'datetime' },
+    tokenizer        => { type => 'string' },
+    track_scores     => { type => 'bool' },
+    transport        => { type => 'bool' },
+    ts               => { type => 'bool' },
+    ttl              => { type => 'duration' },
+    type             => { type => 'string' },
+    types            => { type => 'list' },
+    update_all_types => { type => 'bool' },
+    v                => { type => 'bool' },
+    verbose          => { type => 'bool' },
+    verify           => { type => 'bool' },
+    version          => { type => 'number' },
+    version_type     => {
         type    => 'enum',
         options => [ 'internal', 'external' ]
     },
@@ -279,7 +286,7 @@ Search::Elasticsearch::Util::API::QS - A utility class for query string paramete
 
 =head1 VERSION
 
-version 1.20
+version 1.99
 
 =head1 DESCRIPTION
 
